@@ -1,10 +1,6 @@
 from trapper.data.data_adapters import DataAdapter, DataAdapterForQuestionAnswering
 from trapper.data.data_collator import DataCollator, InputBatch, InputBatchTensor
-from trapper.data.data_processors import (
-    DataProcessor,
-    SquadDataProcessor,
-    SquadQuestionAnsweringDataProcessor,
-)
+from trapper.data.data_processors import DataProcessor, SquadDataProcessor
 from trapper.data.data_processors.data_processor import IndexedInstance
 from trapper.data.dataset_loader import DatasetLoader
 from trapper.data.dataset_reader import DatasetReader
